\name{axis.break}
\alias{axis.break}
\title{ Place a "break" mark on an axis }
\description{
 Places a "break" mark on an axis on an existing plot
}
\usage{axis.break(axis=1,breakpos,bgcol="white",breakcol="black",
  style="slash",brw=0.02)}
\arguments{
 \item{axis}{which axis to break}
 \item{breakpos}{where to place the break in user units}
 \item{bgcol}{the color of the plot background}
 \item{breakcol}{the color of the "break" marker}
 \item{style}{Either \code{slash} or \code{zigzag}}
 \item{brw}{break width relative to plot width}
}
}
\value{nil}
\author{Jim Lemon}
\examples{
 plot(3:10)
 axis.break(1,0.9)
 axis.break(2,2.9,style="zigzag")
}
\keyword{misc}

\eof
\name{boxed.labels}
\alias{boxed.labels}
\title{ Place labels in boxes }
\description{
 Places labels in boxes on an existing plot
}
\usage{boxed.labels(x,y,labels,col="white",border=TRUE,xpad=0.6,ypad=0.6,...)}
\arguments{
 \item{x,y}{x and y position of the centers of the labels}
 \item{col}{The color of the rectangles on which the labels are displayed.}
 \item{labels}{Text strings}
 \item{border}{Whether to draw borders around the rectangles.}
 \item{xpad,ypad}{Half the value of the proportion of the rectangles to the
  extent of the text within.}
 \item{...}{additional arguments passed to \code{text}.}
}
\details{
 This function is best for regularly spaced labels where overlapping is
 not a problem. See \code{thigmophobe.labels} for squeezing labels in tight
 places.
}
\value{nil}
\author{Jim Lemon}
\seealso{\code{spread.labels}, \code{thigmophobe.labels}}
\examples{
 x<-rnorm(10)
 y<-rnorm(10)
 plot(x,y,type="p")
 nums<-c("one","two","three","four","five","six","seven","eight","nine","ten")
 boxed.labels(x,y-0.1,nums)
}
\keyword{misc}

\eof
\name{clock24.plot}
\title{clock24.plot}
\usage{
 clock24.plot(lengths,clock.pos,rp.type="r",...)
}
\alias{clock24.plot}
\arguments{
 \item{lengths}{numeric data vector. Magnitudes will be represented as
  line lengths.}
 \item{clock.pos}{numeric vector of positions on the 'clockface'.
  These must be in decimal hours and will be rescaled to radians.}
 \item{rp.type}{Whether to plot radial lines or a polygon.}
 \item{...}{additional arguments are passed to \code{radial.plot} and
  then to \code{plot}.}
}
\description{
 \code{clock24.plot} displays a plot of radial lines or a polygon
  centered at the midpoint of the plot frame on a 24 hour 'clockface'. 
  In contrast to \code{radial.plot}, the positions are interpreted as 
  beginning at vertical (2400) and moving clockwise.}
}
\value{nil}
\keyword{misc}
\authors{Jim Lemon}
\seealso{\code{polar.plot},\code{radial.plot}}
\examples{
 testlen<-c(rnorm(24)*2+5)
 testpos<-0:23+rnorm(24)/4
 clock24.plot(testlen,testpos,main="Test Clock24")
 par(ask=TRUE)
 # now do a 'daylight' plot
 clock24.plot(testlen[5:19],testpos[5:19],main="Test Clock24 daytime")
 par(ask=FALSE)
}

\eof
\name{floating.pie}
\alias{floating.pie}
\title{Display a floating pie chart}
\description{
 Displays a pie chart at an arbitrary position on an existing plot
}
\usage{floating.pie(xpos,ypos,x,edges=200,radius=1,col=NULL,...)}
\arguments{
 \item{xpos,ypos}{x and y position of the center of the pie chart}
 \item{x}{a numeric vector for which each value will be a sector}
 \item{edges}{the number of lines forming a circle}
 \item{radius}{the radius of the pie in user units}
 \item{col}{the colors of the sectors - defaults to \code{rainbow}}
 \item{...}{graphical parameters passed to \code{polygon}}
}
\value{
 The bisecting angle of the sectors in radians. Useful for placing
 text labels for each sector.
}
\author{Jim Lemon}
\seealso{\code{pie.labels}, \code{boxed.labels}}
\examples{
 pieval<-c(2,4,6,8)
 plot(1:5,type="n")
 floating.pie(3,3,pieval)
}
\keyword{misc}

\eof
\name{gradient.rect}
\title{gradient.rect}
\usage{
 gradient.rect(xleft,ybottom,xright,ytop,reds,greens,blues,nslices=20,
  gradient="x")
}
\alias{gradient.rect}
\arguments{
 \item{xleft,xright,ybottom,ytop}{Positions of the relevant corners
  of the desired rectangle, as in \code{rect}.}
 \item{reds,greens,blues}{vectors of the values of the color components
  either as 0 to 1 or ,if any value is greater than 1, 0 to 255.}
 \item{nslices}{The number of sub-rectangles that will be drawn.}
 \item{gradient}{whether the gradient should be horizontal (x) or vertical.}
}
\description{
 \code{gradient.rect} draws a rectangle consisting of \code{nslices}
  subrectangles, each of the color specified by the respective triplet
  in \code{reds}, \code{greens} and \code{blues}. The rectangle is
  'sliced' in the direction specified by \code{gradient}.}
}
\value{the vector of hexadecimal color values}
\authors{Jim Lemon}
\seealso{\code{rgb.to.hex}}
\examples{
 # get an empty box
 plot(0:10,type="n",axes=FALSE)
 # first try a "rainbow"
 gradient.rect(1,0,3,6,c(1,0),c(seq(0,1,length=10),seq(1,0,length=10)),c(0,1),
  gradient="y")
 # now a "danger gradient"
 gradient.rect(4,0,6,6,c(seq(0,1,length=10),rep(1,10)),
  c(rep(1,10),seq(1,0,length=10)),c(0,0),gradient="y")
 # finally a real mess
 gradient.rect(7,0,9,6,c(1,0),rescale(rnorm(20),c(0,1)),c(1,0),c(0,1),
  gradient="y")
}
\keyword{misc}

\eof
\name{pie.labels}
\alias{pie.labels}
\title{ Place labels on a pie chart }
\description{
 Places labels on a pie chart
}
\usage{pie.labels(x,y,angles,labels,radius=1,col="white",border=TRUE,...)}
\arguments{
 \item{x,y}{x and y position of the center of the pie chart}
 \item{angles}{A numeric vector representing angles in radians. This is
  return value of \code{floating.pie}.}
 \item{labels}{Text strings to label each sector.}
 \item{radius}{The radius at which to place the labels in user units. The
  default is 1.}
 \item{col}{The color of the rectangles on which the labels are displayed.}
 \item{border}{Whether to draw borders around the rectangles.}
 \item{...}{Arguments passed to \code{boxed.labels}.}
}
\value{nil}
\author{Jim Lemon}
\seealso{\code{floating.pie}, \code{boxed.labels}}
\examples{
 pieval<-c(2,4,6,8)
 plot(1:5,type="n")
 bisect.angles<-floating.pie(3,3,pieval)
 pie.labels(3,3,bisect.angles,c("two","four","six","eight"))
}
\keyword{misc}

\eof
\name{polar.plot}
\title{polar.plot}
\usage{
 polar.plot(lengths,polar.pos,labels,label.pos,rp.type="r",...)
}
\alias{polar.plot}
\arguments{
 \item{lengths}{numeric data vector. Magnitudes will be represented as
  line lengths.}
 \item{polar.pos}{numeric vector of positions on a 0:360 degree circle.
  These will be rescaled to radians.}
 \item{labels}{text labels to place on the periphery of the circle. This 
  defaults to labels every 20 degrees. For no labels, pass an empty string.}
 \item{label.pos}{positions of the labels in degrees}
 \item{rp.type}{Whether to plot radial lines or a polygon.}
 \item{...}{additional arguments passed to \code{radial.plot} and
  then to \code{plot}.}
}
\description{
 \code{polar.plot} displays a plot of radial lines or a polygon centered 
  at the midpoint of the plot frame on a 0:(2*pi) circle.
  Positions are interpreted as beginning at the right and
  moving counterclockwise.}
}
\value{nil}
\authors{Jim Lemon}
\keyword{misc}
\seealso{\code{radial.plot}}
\examples{
 testlen<-c(rnorm(36)*2+5)
 testpos<-seq(0,350,by=10)
 polar.plot(testlen,testpos,main="Test Polar Plot")
}

\eof
\name{radial.plot}
\title{radial.plot}
\usage{
 radial.plot(lengths,radial.pos,radial.range,labels,label.pos,rp.type="r",
 label.prop=1.1,main="",xlab="",ylab="",...)
}
\alias{radial.plot}
\arguments{
 \item{lengths}{numeric data vector. Magnitudes will be represented as
  line lengths or polygon vertices.}
 \item{radial.pos}{numeric vector of positions in radians. These are
  interpreted as beginning at the right (0 radians) and moving
  counterclockwise.}
 \item{radial.range}{range of positions in radians. This allows a vector
  of lines to be spread over part of the 2*pi range of the plot.}
 \item{labels}{character strings to be placed at the outer ends of
  the lines. If set to NULL, will suppress printing of labels,
  but if missing, the radial positions will be used.}
 \item{label.pos}{the positions of the labels as distance from the
  'center' of the plot. If missing, they will be placed at 1.1
  times the maximum of \code{lengths}.}
 \item{rp.type}{whether to draw radial lines or a polygon.}
 \item{label.prop}{the label position radius as aproportion of the 
  maximum line length.}
 \item{main}{The title for the plot.}
 \item{xlab,ylab}{Normally x and y axis labels are suppressed.}
 \item{...}{additional arguments are passed to \code{plot}.}
}
\description{
 \code{radial.plot} displays a plot of radial lines or a polygon
  centered at the midpoint of the plot frame, the lengths or
  vertices corresponding to the numeric magnitudes of the data values.
}
\value{nil}
\details{The radial.plot family of plots is useful for illustrating
 cyclic data such as wind direction and velocity, activity at different
 times of the day, and so on. While \code{radial.plot} actually does
 the plotting, another function is usually called for specific types
 of cyclic data.}
\authors{Jim Lemon}
\keyword{misc}
\seealso{\code{polar.plot},\code{clock24.plot}}
\examples{
 testlen<-rnorm(10)*2+5
 testpos<-seq(0,18*pi/10,length=10)
 testlab<-letters[1:10]
 radial.plot(testlen,testpos,main="Test Radial Lines")
 par(ask=TRUE)
 testlen<-c(sin(seq(0,1.98*pi,length=100))+2+rnorm(100)/10)
 testpos<-seq(0,1.98*pi,length=100)
 radial.plot(testlen,testpos,rp.type="p",main="Test Polygon",col="blue")
 par(ask=FALSE)
}

\eof
\name{rescale}
\title{rescale}
\usage{
 rescale(x,newrange)
}
\alias{rescale}
\arguments{
 \item{x}{A numeric vector.}
 \item{newrange}{The minimum and maximum value of the range into which
  \code{x} will be scaled.}
}
\description{
 \code{rescale} performs a simple linear conversion of \code{x} into the
  range specified by \code{newrange}. Only numeric vectors with some variation
  will be accepted.}
}
\value{On success, the rescaled vector.}
\authors{Jim Lemon}
\examples{
 # scale one vector into the range of another
 normal.counts<-tabulate(cut(rnorm(100),breaks=seq(-3,3,by=1)))
 normal.density<-rescale(dnorm(seq(-3,3,length=100)),range(normal.counts))
 # now plot them
 plot(c(-2.5,-1.5,-0.5,0.5,1.5,2.5),normal.counts,type="h")
 lines(seq(-3,3,length=100),normal.density)
}
\keyword{misc}

\eof
\name{rgb.to.hex}
\title{rgb.to.hex}
\usage{
 rgb.to.hex(rgb,scale.up=TRUE)
}
\alias{rgb.to.hex}
\arguments{
 \item{rgb}{A numeric vector of length at least 3 representing the relative
  red, green and blue values. Each value must be between 0 and 255.}
 \item{scale.up}{A logical value indicating whether to scale up when all
  values are between 0 and 1.}
}
\description{
 \code{rgb.to.hex} converts the first three values in \code{rgb} to a six
 digit hexadecimal string preceded by a hash character. If all three values 
 are between 0 and 1, all are scaled up to a range of 0-255 unless 
 \code{scale.up} is FALSE.}
}
\value{hexadecimal color}
\authors{Jim Lemon}
\seealso{\code{gradient.rect}}
\examples{
 # a light purple color in a 0-1 format
 rgb.to.hex(c(0.9,0.5,0.9))
 # supressing the scaling gives almost pure black
 rgb.to.hex(c(0.9,0.5,0.9),FALSE)
}
\keyword{misc}

\eof
\name{spread.labels}
\alias{spread.labels}
\title{ Spread labels for irregularly spaced values }
\description{
 Places labels for irregularly spaced values in a regular staggered order
}
\usage{spread.labels(x,y,labels=NULL,offset,col="white",border=FALSE,...)}
\arguments{
 \item{x,y}{x and y data values}
 \item{labels}{text strings}
 \item{offset}{How far away from the data points to place the labels.}
 \item{col}{The color of the background rectangles on which to place the
  labels.}
 \item{border}{Whether to draw a border around the labels.}
 \item{...}{additional arguments passed to \code{boxed.labels}.}
}
\details{
 This function is mainly useful when labeling irregularly spaced data points
 that are "spread out" along one dimension. It places the labels regularly
 spaced and staggered on the long dimension of the data, drawing lines from
 each label to the point it describes.
}
\value{nil}
\author{Jim Lemon}
\seealso{\code{boxed.labels}}
\examples{
 x<-rnorm(10)/10
 y<-sort(rnorm(10))
 plot(x,y,xlim=c(-1,1),type="p")
 nums<-c("one","two","three","four","five","six","seven","eight","nine","ten")
 spread.labels(x,y,nums,0.5)
}
\keyword{misc}

\eof
\name{staxlab}
\alias{staxlab}
\title{ Place staggered labels on an axis }
\description{
 Places labels on an axis in a regular staggered order
}
\usage{staxlab(side=1,at,labels,nlines=2,top.line=0.5,line.spacing=0.8)}
\arguments{
 \item{side}{axis on which to place the labels, as in \code{axis}}
 \item{at}{where to place the labels in user units, as in \code{axis}}
 \item{labels}{text strings}
 \item{nlines}{How many lines to use to stagger the labels.}
 \item{top.line}{Distance from the axis to place the first line of text.}
 \item{line.spacing}{Spacing between lines of text labels.}  
}
\details{
 This function is mainly useful when either long axis labels or a large
 number of labels are to be placed without overlapping. It places the 
 labels regularly spaced and staggered along the axis specified.
}
\value{nil}
\author{Jim Lemon}
\seealso{\code{mtext}}
\examples{
 plot(1:10,axes=FALSE)
 box()
 nums<-c("one","two","three","four","five","six","seven","eight","nine","ten")
 staxlab(1,1:10,nums)
}
\keyword{misc}

\eof
\name{thigmophobe}
\title{thigmophobe}
\usage{
 thigmophobe(x,y)
}
\alias{thigmophobe}
\arguments{
 \item{x,y}{Numeric data vectors. Typically the x/y coordinates of
  plotted points.}
}
\description{
 \code{thigmophobe} returns the direction (as 1|2|3|4 - see pos= in 
  \code{text}) away from the nearest point to each of the points 
  described by \code{x} and \code{y}.
}
\details{
 Typically used to get the offset to automatically place labels on
 a scatterplot or similar using \code{thigmophobe.labels} to avoid 
 overlapping labels. The name means "one who fears being touched".
}
\value{
 A vector of directions away from the point nearest to each point.
}
\keyword{misc}
\authors{Jim Lemon}
\seealso{\code{thigmophobe.labels}}
\examples{
 x<-rnorm(10)
 y<-rnorm(10)
 thigmophobe(x,y)
}

\eof
\name{thigmophobe.labels}
\title{thigmophobe.labels}
\usage{
 thigmophobe.labels(x,y,labels=1:length(x),...)
}
\alias{thigmophobe.labels}
\arguments{
 \item{x,y}{Numeric data vectors. Typically the x/y coordinates of
  plotted points.}
 \item{labels}{A vector of strings that will be placed adjacent to
  each point. Defaults to the indices of the coordinates.}
 \item{...}{additional arguments are passed to \code{text}}.
}
\description{
 \code{thigmophobe.labels} places labels adjacent to each point, 
  offsetting each label in the direction returned by 
  \code{thigmophobe}.}
}
\details{
 Typically used to automatically place labels on a scatterplot or 
 similar to avoid overlapping labels.
}
\value{
 A vector of directions away from the point nearest to each point.
}
\keyword{misc}
\authors{Jim Lemon}
\seealso{\code{thigmophobe}}
\examples{
 x<-rnorm(10)
 y<-rnorm(10)
 xlim<-range(x)
 xspace<-(xlim[2]-xlim[1])/20
 xlim<-c(xlim[1]-xspace,xlim[2]+xspace)
 ylim<-range(y)
 yspace<-(ylim[2]-ylim[1])/20
 ylim<-c(ylim[1]-yspace,ylim[2]+yspace)
 plotlabels<-
  c("one","two","three","four","five","six","seven","eight","nine","ten")
 plot(x=x,y=y,xlim=xlim,ylim=ylim)
 thigmophobe.labels(x,y,plotlabels,col=2:11)
}

\eof
